from setuptools import setup

setup(
    name='edosnahb',
    version='1.0.0',
    description='Description',
    author='edosnahb',
    author_email='your@email.com',
    packages=[],
    install_requires=[],  # List any dependencies required by your module
)
